.. include:: ../README.rst

.. toctree::
   :hidden:

   introduction
   performance
   performance-load
   performance-runtime
   performance-workload
   implementation
   performance-scale
   development
   history
   sortedlist
   sorteddict
   sortedset
   pycon-2016-talk
   sf-python-2015-lightning-talk
   djangocon-2015-lightning-talk
